==> hbase-procedure-2.0.0-sources.jar: org/apache/hadoop/hbase/procedure2/LockStatus.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hbase.procedure2;

import org.apache.yetus.audience.InterfaceAudience;

/**
 * Interface to get status of a Lock without getting access to acquire/release lock.
 * Currently used in MasterProcedureScheduler where we want to give Queues access to lock's
 * status for scheduling purposes, but not the ability to acquire/release it.
 */
@InterfaceAudience.Private
public interface LockStatus {
  boolean isLocked();

  boolean hasExclusiveLock();

  boolean isLockOwner(long procId);

  boolean hasParentLock(final Procedure proc);

  boolean hasLockAccess(final Procedure proc);

  Procedure<?> getExclusiveLockOwnerProcedure();

  long getExclusiveLockProcIdOwner();

  int getSharedLockCount();
}

==> hbase-procedure-2.0.2-sources.jar: org/apache/hadoop/hbase/procedure2/LockStatus.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hbase.procedure2;

import org.apache.yetus.audience.InterfaceAudience;

/**
 * Interface to get status of a Lock without getting access to acquire/release lock.
 * Currently used in MasterProcedureScheduler where we want to give Queues access to lock's
 * status for scheduling purposes, but not the ability to acquire/release it.
 */
@InterfaceAudience.Private
public interface LockStatus {
  boolean isLocked();

  boolean hasExclusiveLock();

  boolean isLockOwner(long procId);

  boolean hasParentLock(Procedure<?> proc);

  boolean hasLockAccess(Procedure<?> proc);

  Procedure<?> getExclusiveLockOwnerProcedure();

  long getExclusiveLockProcIdOwner();

  int getSharedLockCount();
}
